@@ -9,12 +9,11 @@ use Net::Frame::Layer::ICMPv4::Echo;
 
 my $ip = Net::Frame::Layer::IPv4->new(protocol => NF_IPv4_PROTOCOL_ICMPv4);
 
-my $icmp = Net::Frame::Layer::ICMPv4->new(
-   icmpType => Net::Frame::Layer::ICMPv4::Echo->new(payload => 'test'),
-);
+my $icmp = Net::Frame::Layer::ICMPv4->new;
+my $type = Net::Frame::Layer::ICMPv4::Echo->new(payload => 'test');
 
 my $oSimple = Net::Frame::Simple->new(
-   layers => [ $ip, $icmp, ],
+   layers => [ $ip, $icmp, $type, ],
 );
 print $oSimple->print."\n";
 print unpack('H*', $oSimple->raw)."\n";
