@@ -1,5 +1,5 @@
 #
-# $Id: Redirect.pm 49 2009-05-31 13:15:34Z gomor $
+# $Id: Redirect.pm 53 2012-01-31 20:27:06Z gomor $
 #
 package Net::Frame::Layer::ICMPv4::Redirect;
 use strict; use warnings;
@@ -14,10 +14,12 @@ __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 
 sub new {
-   shift->SUPER::new(
+   my $self = shift->SUPER::new(
       gateway => '127.0.0.1',
       @_,
    );
+
+   return $self;
 }
 
 sub getLength { 4 }
@@ -43,11 +45,27 @@ sub unpack {
    return $self;
 }
 
+sub encapsulate {
+   my $self = shift;
+
+   return $self->nextLayer if $self->nextLayer;
+
+   if ($self->payload) {
+      my $pLen = length($self->payload);
+      if ($pLen < 40) {
+         $self->payload($self->payload.("\x00" x (40 - $pLen)));
+      }
+      return 'IPv4';
+   }
+
+   return NF_LAYER_NONE;
+}
+
 sub print {
    my $self = shift;
 
    my $l = $self->layer;
-   sprintf "$l: gateway:%s", $self->gateway;
+   return sprintf "$l: gateway:%s", $self->gateway;
 }
 
 1;
@@ -157,7 +175,7 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2006-2009, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006-2012, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
